@@ -16,7 +16,6 @@ import os
 import logging
 
 import tpDcc
-from tpDcc.libs.python import path as path_utils
 
 import artellapipe.register
 from artellapipe.core import abstract, defines
@@ -128,9 +127,8 @@ class ArtellaAsset(abstract.AbstractAsset, object):
                     template.name, template.pattern, template_dict))
             return None
 
-        project_drive = artellapipe.project.get_drive()
-        if not asset_path.startswith(project_drive):
-            asset_path = path_utils.clean_path(os.path.join(project_drive, os.path.splitdrive(asset_path)[-1]))
+        asset_path = os.path.expandvars(asset_path)
+        asset_path = artellapipe.FilesMgr().prefix_path_with_project_path(asset_path)
 
         return asset_path
 
